/**
 * TenorDatenContainer.java
 * eu.gronos.kostenrechner.controller (Kostenrechner)
 */
package eu.gronos.kostenrechner.controller;

import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlRootElement;

import eu.gronos.kostenrechner.controller.VerfahrensDatenContainer.Dateikopf;
import eu.gronos.kostenrechner.interfaces.Tenorierend;
import eu.gronos.kostenrechner.model.tenordaten.HauptsacheVerhaeltnis;
import eu.gronos.kostenrechner.model.tenordaten.KostenTragungsVerhaeltnis;
import eu.gronos.kostenrechner.model.tenordaten.VollstreckungsVerhaeltnis;

/**
 * Containerklasse, um alle Entscheidungstexte eines {@link Tenorierend} wie
 * auch dessen strukturierten Berechnungsdaten aufnehmen und für Debug- und
 * Support-Zwecke als XML speichern zu können
 *
 * @author Peter Schuster (setrok)
 * @date 02.07.2018
 *
 */
@XmlRootElement(name = "SchustersKostenTenorDatenXML", namespace = "http://www.kostentenor.de/tenor")
public class TenorDatenContainer {

	public static class HauptsacheEntscheidungsElemente {
		@XmlElement(name = "HauptsacheentscheidungsText")
		public String text;

		@XmlElement(name = "hauptsacheVerurteilung")
		@XmlElementWrapper(name = "hauptsacheVerurteilungen")
		public List<HauptsacheVerhaeltnis> prozessverhaeltnisse = new ArrayList<HauptsacheVerhaeltnis>();
	}

	public static class KostenGrundEntscheidungsElemente {
		@XmlElement(name = "kostengrundentscheidungsText")
		public String text;

		@XmlElement(name = "kostenTragung")
		@XmlElementWrapper(name = "kostenTragungsEntscheidungen")
		public List<KostenTragungsVerhaeltnis> prozessverhaeltnisse = new ArrayList<KostenTragungsVerhaeltnis>();
	}

	public static class VollstreckbarkeitsEntscheidungsElemente {
		@XmlElement(name = "vollstreckbarkeitsEntscheidungsText")
		public String text;

		@XmlElement(name = "vollstreckungsVerhaeltnis")
		@XmlElementWrapper(name = "vollstreckungsVerhaeltnisse")
		public List<VollstreckungsVerhaeltnis> prozessverhaeltnisse = new ArrayList<VollstreckungsVerhaeltnis>();
	}

	public static class StreitwertEntscheidungsElemente {
		@XmlElement(name = "streitwertEntscheidungText")
		public String text;

		@XmlElement(name = "streitwert")
		@XmlElementWrapper(name = "streitwerte")
		public List<Long> streitwerte = new ArrayList<Long>();
	}

	public static class SonstigeEntscheidungsElemente {
		@XmlElement(name = "sonstigerEntscheidungsText")
		public String text;

		// TODO ArrayList
	}

	/**
	 * Tabulierend sieht hier Object[][] tableCellValues vor, der von Class<?>[]
	 * columnClasses und String[] columnHeaders erklärt wird. Das lässt sich wohl
	 * auf XML schlecht übertragen... Aber es gibt eine begrenzte Anzahl möglicher
	 * Klassen, aus denen die Begründung zusammen gesetzt sein kann, nämlich String
	 * für die Zeilen-/Spalten-Überschriften und Double für die Inhalte.
	 */
	public static class BegruendungsElemente {
		@XmlElement(name = "begruendungText")
		public String text;

		@XmlElement(name = "caret")
		@XmlElementWrapper(name = "range")
		public int[] range = new int[2];

		@XmlElement(name = "spaltenUeberschrift")
		@XmlElementWrapper(name = "spaltenUeberschriften")
		public List<String> columnHeaders;
		
		@XmlElement(name = "zeilenUeberschrift")
		@XmlElementWrapper(name = "zeilenUeberschriften")
		public List<String> rowHeaders;
		
		//TODO wie bei mehrdimensionalen Listen?
		@XmlElement(name = "zeile")
		@XmlElementWrapper(name = "zeilen")
		public List<List<Double>> doubleData;
	}

	@XmlElement
	public String berechnungsTyp;

	@XmlElement(name = "programminfo")
	public Dateikopf dateikopf = new Dateikopf();

	@XmlElement(name = "hauptsache")
	public HauptsacheEntscheidungsElemente hauptsacheEntscheidung = new HauptsacheEntscheidungsElemente();

	@XmlElement(name = "kosten")
	public KostenGrundEntscheidungsElemente kostenEntscheidung = new KostenGrundEntscheidungsElemente();

	@XmlElement(name = "vorlaeufigVollstreckbar")
	public VollstreckbarkeitsEntscheidungsElemente vollstreckbarkeitsEntscheidung = new VollstreckbarkeitsEntscheidungsElemente();

	@XmlElement(name = "streitwertEntscheidung")
	public StreitwertEntscheidungsElemente streitwertEntscheidung = new StreitwertEntscheidungsElemente();

	@XmlElement(name = "sonstiges")
	public SonstigeEntscheidungsElemente sonstigeEntscheidung = new SonstigeEntscheidungsElemente();

	@XmlElement(name = "begruendung")
	public BegruendungsElemente begruendung = new BegruendungsElemente();
}
