/**
 * StreitgenossenBaumbachAction.java
 * eu.gronos.kostenrechner.view.panel (Kostenrechner)
 */
package eu.gronos.kostenrechner.controller.baumbach;

import java.awt.event.ActionEvent;

import eu.gronos.kostenrechner.controller.BeschriebeneAktion;
import eu.gronos.kostenrechner.controller.VerfahrensDatenContainer;
import eu.gronos.kostenrechner.controller.files.VerfahrensDatenContainer2GUI;
import eu.gronos.kostenrechner.logic.baumbach.BaumbachFormel;
import eu.gronos.kostenrechner.view.baumbach.StreitgenossenPanel;
import eu.gronos.kostenrechner.view.helpanderror.FehlerDialog;
import eu.gronos.kostenrechner.view.result.TenorDialog;

/**
 * Der AbstractAction mit dem Namen baumbachBerechnen erzeugt einen Kostentenor
 * nach der Baumbach'schen Kostenformel.
 * 
 * @TODO TODO Werden Werte geprüft?
 *
 * @author Peter Schuster (setrok)
 * @date 10.11.2018
 *
 */
public class StreitgenossenBaumbachAction extends BeschriebeneAktion {
	/**
	 * panel speichert TODO (kommentieren) als StreitgenossenBaumbachAction.
	 */
	private final StreitgenossenPanel panel;
	private static final long serialVersionUID = 8105321861085009090L;

	/**
	 * Konstruktor: TODO (kommentieren)
	 * 
	 * @param name
	 * @param shortDescription
	 * @param mnemonic
	 * @param actionCommandKey
	 * @param streitgenossenPanel TODO
	 */
	public StreitgenossenBaumbachAction(StreitgenossenPanel streitgenossenPanel, String name, String shortDescription,
			int mnemonic, String actionCommandKey) {
		super(name, shortDescription, mnemonic, actionCommandKey);
		panel = streitgenossenPanel;
	}

	@Override
	public void actionPerformed(ActionEvent ae) {
		/*
		 * Wenn Dwbk vorhanden, dann die Werte aller drei Tabellen zusammenfügen,
		 * ansonsten nur die von Klägern und Beklagten.
		 */
		if (!panel.pruefeBaumbachTabellen()) {
			Throwable e = new IllegalArgumentException(StreitgenossenPanel.FEHLER_NIX_PARTEIEN_LANG);
			new FehlerDialog(StreitgenossenPanel.FEHLER_NIX_PARTEIEN, e.getLocalizedMessage(), e).showDialog();
			return;
		}
		try {
			final VerfahrensDatenContainer container = new VerfahrensDatenContainer2GUI().leseAlleWertefuerContainer();
			new TenorDialog(panel.getKostenrechner(),
					new BaumbachFormel(container.allgemein, container.streitgenossen).erzeugeContainer(), container)
							.showDialog();
		} catch (IllegalArgumentException iae) {
			new FehlerDialog(FehlerDialog.FEHLER_BLANKO, StreitgenossenPanel.FEHLER_BERECHNUNG, iae).showDialog();
		}
	}
}