/**
 * StreitgenossenBkAction.java
 * eu.gronos.kostenrechner.view.panel (Kostenrechner)
 */
package eu.gronos.kostenrechner.controller.baumbach;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import eu.gronos.kostenrechner.controller.BeschriebeneAktion;
import eu.gronos.kostenrechner.model.baumbach.BaumbachBeteiligter;
import eu.gronos.kostenrechner.model.baumbach.BeteiligtenTableModel;
import eu.gronos.kostenrechner.model.tenordaten.Beteiligter;
import eu.gronos.kostenrechner.view.baumbach.BeteiligtenHinzufuegenDialog;
import eu.gronos.kostenrechner.view.baumbach.StreitgenossenPanel;
import eu.gronos.kostenrechner.view.helpanderror.FehlerDialog;

/**
 * Der AbstractAction mit dem Namen klgrNeu fügt einen neuen Kläger hinzu.
 * {@link KeyEvent#VK_K} Der AbstractAction mit dem Namen beklagterNeu fügt
 * einen neuen (einzelnen) Beklagten hinzu. {@link KeyEvent#VK_B} Der
 * AbstractAction mit dem Namen drittwiderbeklagterNeu fügt einen neuen
 * Drittwiderbeklagten hinzu. {@link KeyEvent#VK_D}
 *
 * @author Peter Schuster (setrok)
 * @date 10.11.2018
 *
 */
public class StreitgenossenBeteiligterNeuAction extends BeschriebeneAktion {
	private final StreitgenossenPanel panel;
	private static final long serialVersionUID = -6505409262360418812L;
	private int typ;

	/**
	 * Konstruktor: TODO (kommentieren)
	 * 
	 * @param panel            TODO
	 * @param typ              {@link Beteiligter#KLAEGER},
	 *                         {@link Beteiligter#BEKLAGTE} oder
	 *                         {@link Beteiligter#DRITTWIDERBEKLAGTE}
	 * @param name
	 * @param shortDescription
	 * @param mnemonic
	 * @param actionCommandKey
	 */
	public StreitgenossenBeteiligterNeuAction(StreitgenossenPanel panel, int typ, String name, String shortDescription,
			int mnemonic, String actionCommandKey) {
		super(name, shortDescription, mnemonic, actionCommandKey);
		this.panel = panel;
		this.typ = typ;
	}

	@Override
	public void actionPerformed(ActionEvent ae) {
		beteiligtenHinzufuegen(panel.getTableModel(typ));// panel.btmBeklagte);
	}

	/**
	 * Die Methode beteiligtenHinzufuegen dient dazu, den JDialog
	 * BeteiligtenHinzufuegen zum Hinzufügen eines neuen BaumbaachBeteiligten
	 * auszulesen. Dazu liest sie BaumbachTableModel aus, sofern dieses Werte
	 * enthält, kopiert den letzten Eintrag und fügt den Rückgabewert wieder als
	 * neuen Eintrag der Tabelle hinzu.
	 * 
	 * @param btm das {@link BeteiligtenTableModel}, in das der Beteiligte eingefügt
	 *            werden soll.
	 */
	public void beteiligtenHinzufuegen(BeteiligtenTableModel btm) {
		BaumbachBeteiligter bt;
		if (btm.getRowCount() > 0)
			bt = btm.getRow(btm.getRowCount() - 1);
		else
			bt = new BaumbachBeteiligter(btm.getBeteiligtenTyp(), Beteiligter.WEIBLICH, 0.0, 0.0, false);
		BeteiligtenHinzufuegenDialog btd = new BeteiligtenHinzufuegenDialog(panel.getKostenrechner(), bt,
				panel.isWiderKlageAnzeigen());
		bt = btd.showDialog();
		/*
		 * Wenn versucht wird, mehr als einen Kläger zum btm hinzuzufügen, wirft dieses
		 * eine IllegalArgumentException
		 */
		if (bt != null)
			try {
				btm.addRow(bt);
			} catch (IllegalArgumentException e) {
				new FehlerDialog(FehlerDialog.FEHLER_BLANKO, e.getLocalizedMessage(), e).showDialog();
			}
	}
}