/**
 * StreitgenossenXJustizLesenAction.java
 * eu.gronos.kostenrechner.view.panel (Kostenrechner)
 */
package eu.gronos.kostenrechner.controller.baumbach;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;
import java.io.File;

import javax.swing.JComponent;
import javax.swing.JFileChooser;
import javax.swing.KeyStroke;
import javax.swing.filechooser.FileNameExtensionFilter;

import eu.gronos.kostenrechner.controller.BeschriebeneAktion;
import eu.gronos.kostenrechner.controller.VerfahrensDatenContainer;
import eu.gronos.kostenrechner.controller.files.LadeXjustizController;
import eu.gronos.kostenrechner.view.baumbach.BaumbachAssistentDialog;
import eu.gronos.kostenrechner.view.baumbach.StreitgenossenPanel;

/**
 * Der AbstractAction importiert eine XJustiz-Datei und ruft dann den
 * Baumbach-Assistenten auf. {@link KeyEvent#VK_X}
 *
 * @author Peter Schuster (setrok)
 * @date 10.11.2018
 *
 */
public class StreitgenossenXJustizLesenAction extends BeschriebeneAktion {
	private final StreitgenossenPanel panel;
	private static final long serialVersionUID = 3372100502718641247L;

	/**
	 * Der Konstruktor setzt die Felder der {@link BeschriebeneAktion}
	 * 
	 * @param name             the name ({@link javax.swing.Action#NAME}) for the
	 *                         action; a value of null is ignored
	 * @param shortDescription ({@link javax.swing.Action#SHORT_DESCRIPTION}) The
	 *                         key used for storing a short String description for
	 *                         the action, used for tooltip text.
	 * @param mnemonic         ({@link javax.swing.Action#MNEMONIC_KEY}) The key
	 *                         used for storing an Integer that corresponds to one
	 *                         of the KeyEvent key codes. The value is commonly used
	 *                         to specify a mnemonic.
	 *                         KeyEvent.getExtendedKeyCodeForChar('\u0444')) sets
	 *                         the mnemonic of myAction to Cyrillic letter "Ef".
	 * @param actionCommandKey ({@link javax.swing.Action#ACTION_COMMAND_KEY}) The
	 *                         key used to determine the command String for the
	 *                         ActionEvent that will be created when an Action is
	 *                         going to be notified as the result of residing in a
	 *                         Keymap associated with a {@link JComponent}.
	 * @param acceleratorKey   ({@link javax.swing.Action#ACCELERATOR_KEY}) The key
	 *                         used for storing a KeyStroke to be used as the
	 *                         accelerator for the action.
	 * @param panel            ein Bezug auf das aufrufende
	 *                         {@link StreitgenossenPanel}
	 */
	public StreitgenossenXJustizLesenAction(StreitgenossenPanel panel, String name, String shortDescription,
			int mnemonic, String actionCommandKey, KeyStroke acceleratorKey) {
		super(name, shortDescription, mnemonic, actionCommandKey, acceleratorKey);
		this.panel = panel;
	}

	@Override
	public void actionPerformed(ActionEvent ae) {
		File auswahl = null;
		VerfahrensDatenContainer container = null;
		BaumbachAssistentDialog bad = null;
		JFileChooser jfc = new JFileChooser();
		jfc.setFileFilter(new FileNameExtensionFilter("XML", "xml"));
		int ergebnis = jfc.showOpenDialog(null);
		if (ergebnis == JFileChooser.APPROVE_OPTION) {
			auswahl = jfc.getSelectedFile();
			container = new LadeXjustizController(panel).xJustizLesen(auswahl);
		} else {
			bad = new BaumbachAssistentDialog(this.panel.getKostenrechner(), this.panel.isWiderKlageAnzeigen());
			container = bad.showDialog();
		}
		this.panel.setzeWerte(container.streitgenossen);
	}
}