/**
 * LadeXjustizController.java
 * eu.gronos.kostenrechner.controller.files (Kostenrechner)
 */
package eu.gronos.kostenrechner.controller.files;

import java.io.File;
import java.io.IOException;

import javax.xml.parsers.ParserConfigurationException;

import org.xml.sax.SAXException;

import eu.gronos.kostenrechner.controller.VerfahrensDatenContainer;
import eu.gronos.kostenrechner.view.baumbach.BaumbachAssistentDialog;
import eu.gronos.kostenrechner.view.baumbach.StreitgenossenPanel;
import eu.gronos.kostenrechner.view.helpanderror.FehlerDialog;

/**
 * Ruft für eine gegebene Datei den Xjustiz-Import von
 * {@link XjustizContentHandler} auf und im Anschluss den
 * {@link BaumbachAssistenzDialog}, um das Ergebnis zu verarbeiten.
 *
 * @author Peter Schuster (setrok)
 * @date 11 Nov 2018
 *
 */
public class LadeXjustizController {

	private final StreitgenossenPanel panel;

	/**
	 * Konstruktor: TODO (kommentieren)
	 * 
	 * @param instance
	 */
	public LadeXjustizController(StreitgenossenPanel panel) {
		this.panel = panel;
	}

	/**
	 * Ruft für eine gegebene Datei den Xjustiz-Import von
	 * {@link XjustizContentHandler} auf und im Anschluss den
	 * {@link BaumbachAssistenzDialog}, um das Ergebnis zu verarbeiten.
	 * 
	 * @param datei ein File
	 * @return einen {@link VerfahrensDatenContainer}
	 */
	public VerfahrensDatenContainer xJustizLesen(File datei) {
		BaumbachAssistentDialog bad;
		VerfahrensDatenContainer container = null;
		try {
			container = new XjustizContentHandler(XjustizContentHandler.vonFileNachURI(datei)).parseXjustiz();
		} catch (ParserConfigurationException | SAXException | IOException e) {
			new FehlerDialog(FehlerDialog.FEHLER_BLANKO, e.getLocalizedMessage(), e).showDialog();
		}
		if (container != null) {
			/*
			 * TODO Die übrigen Streitwertfelder erst einmal mit dem Wert aus der
			 * XJustiz-Datei bestücken. So stehen sie schon einmal drin, auch wenn der
			 * Assistent später abgebrochen wird.
			 */
			// TODO setzeAlleStreitwertTextfelder(vdc);
			bad = new BaumbachAssistentDialog(panel.getKostenrechner(), container);
		} else
			bad = new BaumbachAssistentDialog(panel.getKostenrechner(), panel.isWiderKlageAnzeigen());
		container = bad.showDialog();
		/*
		 * Wenn der Assistent mit OK beendet wird, dann die übrigen Streitwertfelder mit
		 * dem Streitwert füllen
		 */
		return container;
	}

}
