/**
 * StreitwertReduktionPanel.java
 * eu.gronos.kostenrechner.view (Kostenrechner)
 */
package eu.gronos.kostenrechner.view.gebuehren;

import java.awt.GridBagConstraints;
import java.awt.event.FocusListener;
import java.awt.event.KeyEvent;
import java.util.ArrayList;
import java.util.Arrays;

import javax.swing.AbstractAction;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFormattedTextField;
import javax.swing.JLabel;
import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.SwingConstants;

import eu.gronos.kostenrechner.Kostenrechner;
import eu.gronos.kostenrechner.controller.KontextMouseListener;
import eu.gronos.kostenrechner.controller.VerfahrensDatenContainer;
import eu.gronos.kostenrechner.controller.VerfahrensDatenContainer.Teilklageruecknahme;
import eu.gronos.kostenrechner.controller.gebuehren.StreitwertReduktionHorcher;
import eu.gronos.kostenrechner.controller.gebuehren.TeilklageMehrkostenAction;
import eu.gronos.kostenrechner.controller.gebuehren.GebuehrNeuAction;
import eu.gronos.kostenrechner.controller.gebuehren.TeilklageQuotenAction;
import eu.gronos.kostenrechner.controller.gebuehren.TeilklageTerminAction;
import eu.gronos.kostenrechner.controller.gebuehren.TeilklageVerschiebenAction;
import eu.gronos.kostenrechner.interfaces.TableModelGebend;
import eu.gronos.kostenrechner.interfaces.WerteLesbar;
import eu.gronos.kostenrechner.model.baumbach.BaumbachBeteiligter;
import eu.gronos.kostenrechner.model.gebuehren.AnwaltsGebuehrenTabelle;
import eu.gronos.kostenrechner.model.gebuehren.GebuehrenSatzTatbestand;
import eu.gronos.kostenrechner.model.gebuehren.GebuehrenTatbestand;
import eu.gronos.kostenrechner.model.gebuehren.GebuehrenTatbestandTableModel;
import eu.gronos.kostenrechner.model.gebuehren.GerichtsGebuehrenTabelle;
import eu.gronos.kostenrechner.model.tenordaten.Beteiligter;
import eu.gronos.kostenrechner.view.GitterBeutelBeschraenkungen;
import eu.gronos.kostenrechner.view.HinzufuegenDialog;
import eu.gronos.kostenrechner.view.KostenJPanel;
import eu.gronos.kostenrechner.view.baumbach.StreitgenossenPanel;
import eu.gronos.kostenrechner.view.helpanderror.FehlerDialog;

/**
 * Diese von {@link KostenJPanel} abgeleitete Klasse nimmt die
 * Oberflächenelemente für die Streitwertreduktion auf.
 *
 * @author Peter Schuster (setrok)
 * @version
 * @date 13.06.2018
 *
 */
public class TeilklageruecknahmePanel extends KostenJPanel
		implements WerteLesbar<VerfahrensDatenContainer.Teilklageruecknahme>, TableModelGebend<GebuehrenTatbestandTableModel> {
	private static final long serialVersionUID = 1618328009895591401L;
	private static final TeilklageruecknahmePanel instance = new TeilklageruecknahmePanel();
	private Kostenrechner kostenrechner;
	JComboBox<Beteiligter> cbBeklagte;
	JComboBox<Beteiligter> cbKlaeger;
	private JFormattedTextField ftfStreitwertVorher;
	public JTable tabVorher;
	private GebuehrenTatbestandTableModel gttmVorher;
	private final AbstractAction neueGebuehrVorherAction = new GebuehrNeuAction(this,
			"Neue Gebühr (vor Teilklagerücknahme entstanden)",
			"<html><b>Neue Gebühr (vor Teilklagerücknahme entstanden)</b><br>Fügt einen vor der Teilklagerücknahme entstandenen Gebührentatbestand <br>in die (obere) Tabelle ein.</html>",
			KeyEvent.VK_V, "gebuehr-vorher", TABLE_VORHER);
	private final AbstractAction neueGebuehrNachherAction = new GebuehrNeuAction(this, 
			"Neue Gebühr (nach Teilklagerücknahme entstanden)",
			"<html><b>Neue Gebühr (nach Teilklagerücknahme entstanden)</b><br>Fügt einen nach der Teilklagerücknahme entstandenen Gebührentatbestand <br>in die (untere) Tabelle ein.</html>",
			KeyEvent.VK_N, "gebuehr-nachher", TABLE_NACHHER);
	private final AbstractAction quotenMethodeAction = new TeilklageQuotenAction(this, "Berechne (Quotenmethode)",
			"<html><b>Berechne Quotenmethode</b><br>Erzeugt den Kostentenor nach der Quotenmethode.</html>",
			KeyEvent.VK_Q, "quotenmethode-tenor");
	private final AbstractAction mehrkostenMethodeAction = new TeilklageMehrkostenAction(this,
			"Berechne (Mehrkostenmethode)",
			"<html><b>Berechne Mehrkostenmethode</b><br>Erzeugt den Kostentenor nach der Mehrkostenmethode.</html>",
			KeyEvent.VK_M, "mehrkostenmethode-tenor");

	private JFormattedTextField ftfStreitwertNachher;
	private JFormattedTextField ftfObsiegen;

	private final FocusListener streitwertListener = new StreitwertReduktionHorcher(this);
	public JTable tabNachher;
	private GebuehrenTatbestandTableModel gttmNachher;
	private JPopupMenu pmGttmVorher;
	private JPopupMenu pmGttmNachher;
	public AbstractAction klageruecknahmeTerminAction = new TeilklageTerminAction(this,
			"Fall Teilklagerücknahme vor/im Termin",
			"Leert die Tabelle mit den Gebührentatbeständen und \nfüllt sie mit der Konstellation Teilklagerücknahme vor Anfall der Terminsgebühr",
			KeyEvent.VK_F, "standard-gebuehren");
	private final AbstractAction gebuehrenTbVerschiebenAction = new TeilklageVerschiebenAction(this,
			"Gebühr in die andere Tabelle verschieben",
			"Entfernt den markierten Eintrag aus dieser Tabelle und fügt ihn der jeweils anderen hinzu.", KeyEvent.VK_T,
			"verschiebe-gebuehr");
	public static final String FEHLER_KEINE_GEBUEHREN = "Fehler: Keine Gebühren angefallen!";
	public static final String FEHLER_KEINE_GEBUEHREN_LANG = "Bitte geben Sie zunächst ein welche Gebühren vor und/oder nach der Streitwertreduktion angefallen waren.";
	public static final String VORHER_POPUPLABEL = "Gebühren vorher...";
	public static final String NACHHER_POPUPLABEL = "Gebühren nachher...";
	private static final int TABLE_VORHER = 0;
	private static final int TABLE_NACHHER = 1;

	/**
	 * Der Konstruktor ruft die Oberklasse auf.
	 * 
	 */
	private TeilklageruecknahmePanel() {
		super();
	}

	/**
	 * Das Panel ist als Singelton ausgestatltet. Diese Methode gibt die alleinige
	 * Instanz zurück.
	 * 
	 * @return gibt {@link #instance} als TeilklageruecknahmePanel zurück.
	 */
	public static TeilklageruecknahmePanel getInstance() {
		return instance;
	}

	/**
	 * Die Methode setzt die Oberflächenelemente für die Registerkarte 1
	 * Teilklagerücknahme
	 * 
	 * 
	 * @see eu.gronos.kostenrechner.view.KostenJPanel#buildPanel()
	 */
	@Override
	public void buildPanel() {
		JLabel lblParteien = new JLabel("Parteien:", SwingConstants.RIGHT);
		lblParteien.setDisplayedMnemonic(KeyEvent.VK_P);
		add(lblParteien, GitterBeutelBeschraenkungen.getInstance(0, 0, 1, 1, GridBagConstraints.HORIZONTAL, false));

		Beteiligter[] klBezeichnerListe = BaumbachBeteiligter.getBeteiligtenAuswahlListe(Beteiligter.KLAEGER, true);
		cbKlaeger = new JComboBox<Beteiligter>(klBezeichnerListe);
		cbKlaeger.setRenderer(StreitgenossenPanel.BETEILIGTEN_RENDERER_OHNE_LFDNR);
		lblParteien.setLabelFor(cbKlaeger);
		add(cbKlaeger, GitterBeutelBeschraenkungen.getInstance(1, 0, 1, 1, GridBagConstraints.HORIZONTAL, false));

		Beteiligter[] bkBezeichnerListe = BaumbachBeteiligter.getBeteiligtenAuswahlListe(Beteiligter.BEKLAGTE, true);
		cbBeklagte = new JComboBox<Beteiligter>(bkBezeichnerListe);
		cbBeklagte.setRenderer(StreitgenossenPanel.BETEILIGTEN_RENDERER_OHNE_LFDNR);
		add(cbBeklagte, GitterBeutelBeschraenkungen.getInstance(2, 0, 1, 1, GridBagConstraints.HORIZONTAL, false));

		JLabel lblStreitwertVorReduktion = new JLabel("Streitwert vor Teilklagerücknahme", SwingConstants.RIGHT);
		add(lblStreitwertVorReduktion,
				// GitterBeutelBeschraenkungen.getGitterBeutelBeschraenkungen(0,
				// 2, 1,
				// 1, false, false));
				GitterBeutelBeschraenkungen.getInstance(0, 1, 1, 1, GridBagConstraints.HORIZONTAL, false));

		ftfStreitwertVorher = new JFormattedTextField(KostenJPanel.FORMATTER_INT);
		ftfStreitwertVorher.setColumns(10);
		ftfStreitwertVorher.setText("0");// "15000"
		ftfStreitwertVorher.addFocusListener(HinzufuegenDialog.BEI_FOCUS_MARKIEREN);
		ftfStreitwertVorher.setHorizontalAlignment(JTextField.RIGHT);
		lblStreitwertVorReduktion.setLabelFor(ftfStreitwertVorher);
		add(ftfStreitwertVorher,
				// GitterBeutelBeschraenkungen.getGitterBeutelBeschraenkungen(2,
				// 2, 1,
				// 1, false, false));
				GitterBeutelBeschraenkungen.getInstance(1, 1, 2, 1, GridBagConstraints.HORIZONTAL, false));

		leereWerte();
		tabVorher = new JTable(getGttmVorher());
		entferneTastaturFalle(tabVorher);
		setzeGebuehrenTabelleAussehen(tabVorher);
		JScrollPane scpVorher = new JScrollPane(tabVorher);
		add(scpVorher,
				// GitterBeutelBeschraenkungen.getGitterBeutelBeschraenkungen(0,
				// 3, 3,
				// 1, true, false));
				GitterBeutelBeschraenkungen.getInstance(0, 2, 3, 1, GridBagConstraints.BOTH, false));

		JButton btnNeueGebhrvorher = new JButton(neueGebuehrVorherAction);
		add(btnNeueGebhrvorher,
				GitterBeutelBeschraenkungen.getInstance(0, 3, 3, 1, GridBagConstraints.HORIZONTAL, false));

		JLabel lblStreitwertNachReduktion = new JLabel("Streitwert nach Teilklagerücknahme", SwingConstants.RIGHT);
		add(lblStreitwertNachReduktion,
				// GitterBeutelBeschraenkungen.getGitterBeutelBeschraenkungen(3,
				// 2, 1,
				// 1, false, false));
				GitterBeutelBeschraenkungen.getInstance(0, 4, 1, 1, GridBagConstraints.HORIZONTAL, false));

		setFtfStreitwertNachher(new JFormattedTextField(KostenJPanel.FORMATTER_INT));
		getFtfStreitwertNachher().setColumns(10);
		getFtfStreitwertNachher().setText("0");// "10000"
		getFtfStreitwertNachher().addFocusListener(HinzufuegenDialog.BEI_FOCUS_MARKIEREN);
		getFtfStreitwertNachher().addFocusListener(streitwertListener);
		getFtfStreitwertNachher().setHorizontalAlignment(JTextField.RIGHT);
		lblStreitwertNachReduktion.setLabelFor(getFtfStreitwertNachher());
		add(getFtfStreitwertNachher(),
				// GitterBeutelBeschraenkungen.getGitterBeutelBeschraenkungen(5,
				// 2, 1,
				// 1, false, false));
				GitterBeutelBeschraenkungen.getInstance(1, 4, 2, 1, GridBagConstraints.HORIZONTAL, false));

		tabNachher = new JTable(getGttmNachher());
		entferneTastaturFalle(tabNachher);
		setzeGebuehrenTabelleAussehen(tabNachher);
		JScrollPane scpNachher = new JScrollPane(tabNachher);
		add(scpNachher,
				// GitterBeutelBeschraenkungen.getGitterBeutelBeschraenkungen(3,
				// 3, 3,
				// 1, true, false));
				GitterBeutelBeschraenkungen.getInstance(0, 5, 3, 1, GridBagConstraints.BOTH, false));

		JButton btnNeueGebhrnachher = new JButton(neueGebuehrNachherAction);
		add(btnNeueGebhrnachher,
				GitterBeutelBeschraenkungen.getInstance(0, 6, 3, 1, GridBagConstraints.HORIZONTAL, false));

		JLabel lblLetztlichObsiegt = new JLabel("Letztlich obsiegt:", SwingConstants.RIGHT);
		add(lblLetztlichObsiegt,
				GitterBeutelBeschraenkungen.getInstance(0, 8, 1, 1, GridBagConstraints.HORIZONTAL, false));

		setFtfObsiegen(new JFormattedTextField(KostenJPanel.FORMATTER_INT));
		getFtfObsiegen().setText("0");// "10000"
		getFtfObsiegen().addFocusListener(HinzufuegenDialog.BEI_FOCUS_MARKIEREN);
		getFtfObsiegen().setHorizontalAlignment(JTextField.RIGHT);
		lblLetztlichObsiegt.setLabelFor(getFtfObsiegen());
		add(getFtfObsiegen(),
				GitterBeutelBeschraenkungen.getInstance(1, 8, 2, 1, GridBagConstraints.HORIZONTAL, false));

		JButton btnBerechnequotenmethode = new JButton(quotenMethodeAction);
		add(btnBerechnequotenmethode,
				GitterBeutelBeschraenkungen.getInstance(0, 9, 3, 1, GridBagConstraints.HORIZONTAL, false));

		JButton btnBerechnemehrkostenmethode = new JButton(mehrkostenMethodeAction);
		add(btnBerechnemehrkostenmethode,
				GitterBeutelBeschraenkungen.getInstance(0, 10, 3, 1, GridBagConstraints.HORIZONTAL, false));

		pmGttmVorher = new JPopupMenu(VORHER_POPUPLABEL);
		pmGttmVorher.add(new JMenuItem(VORHER_POPUPLABEL));
		pmGttmVorher.addSeparator();
		pmGttmVorher.add(new JMenuItem(neueGebuehrVorherAction));
		pmGttmVorher.add(new JMenuItem(klageruecknahmeTerminAction));
		pmGttmVorher.add(new JMenuItem(eintragEntfernenAktion));
		pmGttmVorher.add(new JMenuItem(gebuehrenTbVerschiebenAction));
		tabVorher.addMouseListener(new KontextMouseListener(tabVorher, pmGttmVorher));

		pmGttmNachher = new JPopupMenu(NACHHER_POPUPLABEL);
		pmGttmNachher.add(new JMenuItem(NACHHER_POPUPLABEL));
		pmGttmNachher.addSeparator();
		pmGttmNachher.add(new JMenuItem(neueGebuehrNachherAction));
		pmGttmNachher.add(new JMenuItem(klageruecknahmeTerminAction));
		pmGttmNachher.add(new JMenuItem(eintragEntfernenAktion));
		pmGttmNachher.add(new JMenuItem(gebuehrenTbVerschiebenAction));
		tabNachher.addMouseListener(new KontextMouseListener(tabNachher, pmGttmNachher));
	}

	/**
	 * Die Methode leert alle Tabellen der Streitwertreduktion oder füllt sie mit
	 * den Tatbeständen zum Standardfall
	 * 
	 * @param mitInhalt true, wenn die Tabellen mit den Tatbeständen zum
	 *                  Standardfall gefüllt werden sollen.
	 * 
	 */
	public void setzeStandardGebuehren(boolean mitInhalt) {
		if (mitInhalt) {
			setGttmVorher(new GebuehrenTatbestandTableModel(new ArrayList<GebuehrenTatbestand>(
					Arrays.asList(new GebuehrenSatzTatbestand[] { GerichtsGebuehrenTabelle.KV1210,
							AnwaltsGebuehrenTabelle.VV3100, AnwaltsGebuehrenTabelle.VV3100 }))));

			setGttmNachher(new GebuehrenTatbestandTableModel(
					new ArrayList<GebuehrenTatbestand>(Arrays.asList(new GebuehrenSatzTatbestand[] {
							AnwaltsGebuehrenTabelle.VV3104, AnwaltsGebuehrenTabelle.VV3104 }))));
		} else {
			setGttmVorher(new GebuehrenTatbestandTableModel(new ArrayList<GebuehrenTatbestand>()));
			setGttmNachher(new GebuehrenTatbestandTableModel(new ArrayList<GebuehrenTatbestand>()));
		}
		if (tabVorher != null)
			tabVorher.setModel(getGttmVorher());
		if (tabNachher != null)
			tabNachher.setModel(getGttmNachher());
	}

	/**
	 * Die Methode leert alle Tabellen und Textfelder der Streitwertreduktion
	 * 
	 * @see eu.gronos.kostenrechner.interfaces.WerteLesbar#leereWerte()
	 */
	@Override
	public void leereWerte() {
		setzeStandardGebuehren(false);
	}

	/**
	 * Die Methode leert alle Tabellen der Streitwertreduktion oder füllt sie mit
	 * den Tatbeständen zum aus dem
	 * {@link VerfahrensDatenContainer.Teilklageruecknahme}-Behälter. Zudem füllt
	 * sie die {@link JFormattedTextField} mit den Streitwertangaben.
	 * 
	 * @param container ein {@link VerfahrensDatenContainer.Teilklageruecknahme}
	 *                  -Behälter
	 * 
	 * @see eu.gronos.kostenrechner.view.KostenJPanel#setzeWerte(java.lang.Object)
	 */
	@Override
	public void setzeWerte(final Teilklageruecknahme container) {
		cbKlaeger.setSelectedItem(container.parteien.get(0));
		cbBeklagte.setSelectedItem(container.parteien.get(1));
		ftfStreitwertVorher.setText(container.streitwerteUndObsiegen.get(0).toString());
		getFtfStreitwertNachher().setText(container.streitwerteUndObsiegen.get(1).toString());
		getFtfObsiegen().setText(container.streitwerteUndObsiegen.get(2).toString());
		setGttmVorher(new GebuehrenTatbestandTableModel(container.vorher));
		tabVorher.setModel(getGttmVorher());
		setGttmNachher(new GebuehrenTatbestandTableModel(container.nachher));
		tabNachher.setModel(getGttmNachher());
	}

	/**
	 * Die Methode dient dazu, alle Programmzustände in einen
	 * {@link VerfahrensDatenContainer} zu packen
	 * 
	 * @return den Untercontainer von
	 *         {@link VerfahrensDatenContainer#teilklageruecknahme}
	 * 
	 * @see eu.gronos.kostenrechner.view.KostenJPanel#leseWerte()
	 */
	@Override
	public Teilklageruecknahme leseWerte() {
		Teilklageruecknahme container = new Teilklageruecknahme();
		container.parteien.add((Beteiligter) cbKlaeger.getSelectedItem());
		container.parteien.add((Beteiligter) cbBeklagte.getSelectedItem());
		long[] vorherNachherLetztendlich = parseVorherNachherLetztendlich();
		container.streitwerteUndObsiegen.add(vorherNachherLetztendlich[0]);
		container.streitwerteUndObsiegen.add(vorherNachherLetztendlich[1]);
		container.streitwerteUndObsiegen.add(vorherNachherLetztendlich[2]);
		container.vorher = new ArrayList<GebuehrenTatbestand>();
		container.vorher = getGttmVorher().getAllValues();
		container.nachher = new ArrayList<GebuehrenTatbestand>();
		container.nachher = getGttmNachher().getAllValues();
		return container;
	}

	/**
	 * Die Methode dient dazu, eine Referenz auf das Hauptfenster zu übermitteln
	 * 
	 * @param kostenrechner
	 * 
	 * @see eu.gronos.kostenrechner.view.KostenJPanel#setKostenrechner(eu.gronos.kostenrechner.Kostenrechner)
	 */
	@Override
	public void setKostenrechner(Kostenrechner kostenrechner) {
		this.kostenrechner = kostenrechner;
	}

	/**
	 * Die Methode dient dazu, die formatierten Streitwerte wieder zu long zu
	 * machen, indem "," und "." aus den Zeichenketten gestrichen werden.
	 * 
	 * @param fTF das JFormattedTextField mit dem Zahlenwert
	 * 
	 * @return ein long
	 */
	private long extrahiereLong(JFormattedTextField fTF) throws NumberFormatException {
		if (fTF == null)
			return 0L;
		return Long.parseLong(fTF.getText().replace(".", "").replace(",", ""));
	}

	/**
	 * Die Methode parst die JFormattedTextFields für die Streitwertreduktion.
	 * 
	 * @return ein long[] mit den Werten in der Reihenfolge Streitwert vorher,
	 *         Streitwert nachher, letztlich obsiegt.
	 */
	private long[] parseVorherNachherLetztendlich() {
		long[] zwischen = new long[3];
		long vorher;
		long nachher;
		long letztendlich;
		// TODO geht das vielleicht auch mit dem NumberFormatter?
		try {
			vorher = extrahiereLong(ftfStreitwertVorher);
			nachher = extrahiereLong(getFtfStreitwertNachher());
			letztendlich = extrahiereLong(getFtfObsiegen());
		} catch (NumberFormatException nfe) {
			new FehlerDialog("Bitte Ganzzahlen eingeben!",
					"Konnte Eingabe nicht als Ganzzahl lesen: " + nfe.getLocalizedMessage(), nfe).showDialog();
			return new long[] { 0L, 0L, 0L };
		}
		zwischen = new long[] { vorher, nachher, letztendlich };
		return zwischen;
	}

	/**
	 * Die Methode prüft, ob wenigstens eine der beiden
	 * GebuehrenTatbestandTableModels auf dem Tab für die Teilerledigung/-rücknahme
	 * Daten enhtält.
	 * 
	 * @return true, wenn eine der beiden GebuehrenTatbestandTableModels Daten
	 *         enthält; false, wenn beide leer sind.
	 */
	public boolean pruefeGebuehrenTabellen() {
		return getGttmVorher().getRowCount() > 0 || getGttmNachher().getRowCount() > 0;
	}

	/**
	 * Die Methode verschiebt einen Gebührentatbestand aus einer JTable in die
	 * andere.
	 * 
	 * @param ausgang die JTable, aus der die Zeile gelöscht werden soll
	 * @param ziel    die JTable, in die die Zeile verschoben werden soll
	 */
	public void verschiebeGebuehrenTatbestand(JTable ausgang, JTable ziel) {
		if (ausgang == null || ziel == null || ausgang.getSelectedRow() < 0
				|| !(ausgang.getModel() instanceof GebuehrenTatbestandTableModel)
				|| !(ziel.getModel() instanceof GebuehrenTatbestandTableModel))
			return;
		GebuehrenTatbestandTableModel ausgangsModel = (GebuehrenTatbestandTableModel) ausgang.getModel();
		GebuehrenTatbestandTableModel zielModel = (GebuehrenTatbestandTableModel) ziel.getModel();
		int selectedRow = ausgang.getSelectedRow();
		zielModel.addRow(ausgangsModel.getRow(selectedRow));
		ausgangsModel.removeRow(selectedRow);
	}

	/**
	 * @return gibt {@link #ftfStreitwertNachher} als JFormattedTextField zurück.
	 */
	public JFormattedTextField getFtfStreitwertNachher() {
		return ftfStreitwertNachher;
	}

	/**
	 * @param ftfStreitwertNachher d. {@link #ftfStreitwertNachher}, d. gesetzt
	 *                             werden soll als JFormattedTextField
	 */
	public void setFtfStreitwertNachher(JFormattedTextField ftfStreitwertNachher) {
		this.ftfStreitwertNachher = ftfStreitwertNachher;
	}

	/**
	 * @return gibt {@link #ftfObsiegen} als JFormattedTextField zurück.
	 */
	public JFormattedTextField getFtfObsiegen() {
		return ftfObsiegen;
	}

	/**
	 * @param ftfObsiegen d. {@link #ftfObsiegen}, d. gesetzt werden soll als
	 *                    JFormattedTextField
	 */
	public void setFtfObsiegen(JFormattedTextField ftfObsiegen) {
		this.ftfObsiegen = ftfObsiegen;
	}

	/**
	 * @return gibt {@link #kostenrechner} als Kostenrechner zurück.
	 */
	public Kostenrechner getKostenrechner() {
		return kostenrechner;
	}

	/**
	 * Die Methode dient dazu, TODO  (kommentieren) 
	 * 
	 * @param index
	 * @return
	 * 
	 * @see eu.gronos.kostenrechner.interfaces.TableModelGebend#getTableModel(int)
	 */
	@Override
	public GebuehrenTatbestandTableModel getTableModel(int index) {
		if (index == TABLE_VORHER) {
			return getGttmVorher();
		} else if (index == TABLE_NACHHER) {
			return getGttmNachher();
		}
		throw new IndexOutOfBoundsException();
	}

	/**
	 * @return gibt {@link #gttmVorher} als GebuehrenTatbestandTableModel zurück.
	 */
	public GebuehrenTatbestandTableModel getGttmVorher() {
		return gttmVorher;
	}

	/**
	 * @param gttmVorher d. {@link #gttmVorher}, d. gesetzt werden soll als
	 *                   GebuehrenTatbestandTableModel
	 */
	private void setGttmVorher(GebuehrenTatbestandTableModel gttmVorher) {
		this.gttmVorher = gttmVorher;
	}

	/**
	 * @return gibt {@link #gttmNachher} als GebuehrenTatbestandTableModel zurück.
	 */
	public GebuehrenTatbestandTableModel getGttmNachher() {
		return gttmNachher;
	}

	/**
	 * @param gttmNachher d. {@link #gttmNachher}, d. gesetzt werden soll als
	 *                    GebuehrenTatbestandTableModel
	 */
	private void setGttmNachher(GebuehrenTatbestandTableModel gttmNachher) {
		this.gttmNachher = gttmNachher;
	}

}
