/**
 * TooltipHeaderRenderer.java
 * eu.gronos.kostenrechner (Kostenrechner)
 */
package eu.gronos.kostenrechner.view.gebuehren;

import java.awt.Component;

import javax.swing.JComponent;
import javax.swing.JTable;

import eu.gronos.kostenrechner.interfaces.TooltipLieferant;
import sun.swing.table.DefaultTableCellHeaderRenderer;

/**
 * @author Peter Felix Schuster (SchusterP2)
 * @date 11.08.2014
 */
public class TooltipHeaderRenderer extends DefaultTableCellHeaderRenderer {
	private static final long serialVersionUID = 9155034513233553302L;

	/**
	 * Die Methode erfragt die JComponent des
	 * {@link DefaultTableCellHeaderRenderer} und versieht ihn mit einem
	 * Tooltip.
	 * 
	 * @param table
	 *            the <code>JTable</code> that is asking the renderer to draw;
	 *            can be <code>null</code>
	 * @param value
	 *            the value of the cell to be rendered. It is up to the specific
	 *            renderer to interpret and draw the value. For example, if
	 *            <code>value</code> is the string "true", it could be rendered
	 *            as a string or it could be rendered as a check box that is
	 *            checked. <code>null</code> is a valid value
	 * @param isSelected
	 *            true if the cell is to be rendered with the selection
	 *            highlighted; otherwise false
	 * @param hasFocus
	 *            if true, render cell appropriately. For example, put a special
	 *            border on the cell, if the cell can be edited, render in the
	 *            color used to indicate editing
	 * @param row
	 *            the row index of the cell being drawn. When drawing the
	 *            header, the value of <code>row</code> is -1
	 * @param column
	 *            the column index of the cell being drawn
	 * @return the component used for drawing the cell. This method is used to
	 *         configure the renderer appropriately before drawing.
	 * 
	 * @see sun.swing.table.DefaultTableCellHeaderRenderer#getTableCellRendererComponent(javax.swing.JTable,
	 *      java.lang.Object, boolean, boolean, int, int)
	 */
	@Override
	public Component getTableCellRendererComponent(JTable table, Object value,
			boolean isSelected, boolean hasFocus, int row, int column) {
		JComponent component = (JComponent) super
				.getTableCellRendererComponent(table, value, isSelected,
						hasFocus, row, column);
		if (table.getModel() instanceof TooltipLieferant) {
			TooltipLieferant lieferant = (TooltipLieferant) table.getModel();
			component.setToolTipText(lieferant.getTooltipText(column));
		} else
			setToolTipText(getText());
		return component;
	}
}
